@@ -1,3 +1,4 @@
+import sys
 import json
 import requests
 import datetime
@@ -16,20 +17,27 @@ ULTIMATE_HIGHEST_PRICE = 0.35
 # Ultimate maximum number of zero power hours
 SAFE_ZERO_POWER_HOURS = 12
 
+GPIO_HALF_POWER = 14
+GPIO_ZERO_POWER = 15
+
 class HourPrices:
-    def __init__(self):
+    def __init__(self, tomorrow=False):
 
         self.hour_prices = None
 
         while self.hour_prices == None:
-            self.hour_prices = self.__set_hour_prices()
+            self.hour_prices = self.__set_hour_prices(tomorrow)
             # sleep for 1 hour if hour prices are not available
             if self.hour_prices == None:
                 time.sleep(3600)
 
     # Get hour prices for today from curl -X GET "https://api.spot-hinta.fi/Today" -H  "accept: application/json"
-    def __set_hour_prices(self):
-        url = "https://api.spot-hinta.fi/Today"
+    def __set_hour_prices(self, tomorrow=False):
+        if tomorrow:
+            url = "https://api.spot-hinta.fi/Tomorrow"
+        else:
+            url = "https://api.spot-hinta.fi/Today"
+
         response = requests.get(url)
         # check if the response code is ok (200)
         if response.status_code != 200:
@@ -90,19 +98,19 @@ class HeatControl:
         self.lowest_prices = []
         self.hour_prices = []
 
-        self.new_day()
+        self.new_day(False)
 
         self.set_heat()
 
         # Schedule set_heat() to run beginning of every hour
         schedule.every().hour.at(":00").do(self.set_heat)
 
-        # schedule set_prices_for_today() to run every day at 00:00
-        schedule.every().day.at("00:00").do(self.new_day)
+        # schedule getting prices for tomorrow at last hour of today
+        schedule.every().day.at("23:55").do(self.new_day)
 
-    def new_day(self):
+    def new_day(self, tomorrow=True):
 
-        self.set_prices_for_today()
+        self.set_prices_for_today(tomorrow)
 
         # Print half power hours
         print("Half power hours:")
@@ -129,16 +137,16 @@ class HeatControl:
         GPIO.cleanup()
 
     def set_heat_50_percent(self):
-        self.set_rasbperry_pi_gpio_pin(17, True)
-        self.set_rasbperry_pi_gpio_pin(27, False)
+        self.set_rasbperry_pi_gpio_pin(GPIO_HALF_POWER , True)
+        self.set_rasbperry_pi_gpio_pin(GPIO_ZERO_POWER , False)        
 
-    def set_heat_100_percent(self):
-        self.set_rasbperry_pi_gpio_pin(17, True)
-        self.set_rasbperry_pi_gpio_pin(27, True)
+    def set_heat_off(self):
+        self.set_rasbperry_pi_gpio_pin(GPIO_HALF_POWER , False)
+        self.set_rasbperry_pi_gpio_pin(GPIO_ZERO_POWER , True)        
 
     def set_heat_on(self):
-        self.set_rasbperry_pi_gpio_pin(17, False)
-        self.set_rasbperry_pi_gpio_pin(27, False)
+        self.set_rasbperry_pi_gpio_pin(GPIO_HALF_POWER, False)
+        self.set_rasbperry_pi_gpio_pin(GPIO_HALF_POWER, False)
     
     def get_number_of_consecutive_zero_power_hours(self, hour):
         
@@ -163,9 +171,10 @@ class HeatControl:
 
         return max_consecutive(hours)
 
-    def set_prices_for_today(self):
+    def set_prices_for_today(self, tomorrow=False):
 
-        self.hour_prices = HourPrices().hour_prices
+
+        self.hour_prices = HourPrices(tomorrow).hour_prices
 
         self.hour_prices.sort(key=lambda x: x["Rank"], reverse=True)
 
@@ -210,25 +219,28 @@ class HeatControl:
                 reset_heat = False
                 break
 
-        # Set heat on 100 % if we are on ZeroPowerHours
-
         for hour in self.ZeroPowerHours:
             if hour["Hour"] == datetime.datetime.now().hour:
-                # self.set_heat_100_percent()
+                self.set_heat_off()
                 print(str(datetime.datetime.now()) + ": Zero power")
                 reset_heat = False
                 break
 
         if reset_heat:
-            # self.set_heat_on()
+            self.set_heat_on()
             print(str(datetime.datetime.now()) + ": Heat on")
 
 def main():
-    ht = HeatControl()
-    # Keep the program running
-    while True:
-        schedule.run_pending()
-        time.sleep(1)
+        
+        ht = HeatControl()
+        # Keep the program running
+        while True:
+            try:
+                schedule.run_pending()
+                time.sleep(1)
+            except:
+                ht.set_heat_on()
+                print("Unexpected error:", sys.exc_info()[0])
 
 if __name__ == "__main__":
     main()
